@@ -26,6 +26,7 @@ class RobotEyes(object):
     # Keeping this arg to avoid exceptions for those who have added tolerance in the previous versions.
     def __init__(self, tolerance=0):
         self.ROBOT_LIBRARY_LISTENER = self
+        self.lib = 'none'
 
     def open_eyes(self, lib='SeleniumLibrary', tolerance=0, template_id=''):
         self.tolerance = float(tolerance)
@@ -237,17 +238,15 @@ class RobotEyes(object):
         return 'img%s' % str(self.count)
 
     def _end_test(self, data, test):
-        if self.lib.lower() == 'none':
+        if hasattr(self, 'lib') and self.lib.lower() == 'none':
             if self.fail:
                 test.status = 'FAIL'
                 test.message = 'Image dissimilarity exceeds tolerance'
 
     def _close(self):
-        results_folder = self.output_dir.replace(os.getcwd(), '')[1:]
-
-        if self.baseline_dir and results_folder:
+        if self.baseline_dir and self.output_dir:
             thread = Thread(
                 target=generate_report,
-                args=(self.baseline_dir, results_folder, self.actual_dir,)
+                args=(self.baseline_dir, self.output_dir, self.actual_dir,)
             )
             thread.start()
